@@ -313,6 +313,35 @@ RGDAL_GDAL_DATA_Info(void) {
     return(ans);
 }
 
+SEXP
+RGDAL_GDALwithGEOS(void) {
+    SEXP ans;
+
+    PROTECT(ans=NEW_LOGICAL(1));
+
+    CPLPushErrorHandler(CPLQuietErrorHandler);
+    saved_err_no = 0;
+
+    int withGEOS;
+    OGRGeometry *poGeometry1, *poGeometry2;
+    char* pszWKT;
+    pszWKT = (char*) "POINT (10 20)";
+    OGRGeometryFactory::createFromWkt( &pszWKT, NULL, &poGeometry1 );
+    pszWKT = (char*) "POINT (30 20)";
+    OGRGeometryFactory::createFromWkt( &pszWKT, NULL, &poGeometry2 );
+    withGEOS = 1;
+    if (poGeometry1->Union(poGeometry2) == NULL) withGEOS = 0;
+    OGRGeometryFactory::destroyGeometry(poGeometry1);
+    OGRGeometryFactory::destroyGeometry(poGeometry2);
+
+    CPLPopErrorHandler();
+    saved_err_no = 0;
+
+    LOGICAL_POINTER(ans)[0] = withGEOS;
+    UNPROTECT(1);
+
+    return(ans);
+}
 
 SEXP
 RGDAL_NullHandle(void) {
